==========
putshebang
==========


.. image:: https://img.shields.io/pypi/v/putshebang.svg
        :target: https://pypi.python.org/pypi/putshebang

.. image:: https://img.shields.io/travis/faddyy/putshebang.svg
        :target: https://travis-ci.org/faddyy/putshebang


A small tool that helps in adding the appropriate shebang


* Free software: GNU General Public License v3
* Documentation: https://putshebang.readthedocs.io.


Features
--------

* Help in adding the appropriate shebang
* Use in scripts to get shebang of a file using the `shebang` function

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

